Option Explicit On
Option Strict On

''' <summary>
''' A custom DataGridTextBoxColumn that provides some changed functionality, required by the visualizer
''' </summary>
''' <remarks></remarks>
Public Class CustomGridTextBoxColumn
	Inherits DataGridTextBoxColumn

	''' <summary>
	''' When the grid attempts to go into Edit mode, this method will return without calling
	''' into the base class, and so prevents the edit from starting.
	''' </summary>
	''' <param name="source"></param>
	''' <param name="rowNum"></param>
	''' <param name="bounds"></param>
	''' <param name="readOnly"></param>
	''' <param name="displayText"></param>
	''' <param name="cellIsVisible"></param>
	''' <remarks></remarks>
	Protected Overrides Sub Edit(ByVal source As CurrencyManager, ByVal rowNum As Integer, ByVal bounds As System.Drawing.Rectangle, ByVal [readOnly] As Boolean, ByVal displayText As String, ByVal cellIsVisible As Boolean)
		Return
	End Sub

	''' <summary>
	''' The grid normally paints the active cell with a different colour to the other cells.
	''' As our grid is read-only, this isn't a desirable effect. This overridden Paint method
	''' ensures that the cell is always painted to look the same, regardless of whether it is
	''' active or not. We will also render Null values in grey to distinguish them from the
	''' string "(null)".
	''' </summary>
	''' <param name="g"></param>
	''' <param name="bounds"></param>
	''' <param name="source"></param>
	''' <param name="rowNum"></param>
	''' <param name="backBrush"></param>
	''' <param name="foreBrush"></param>
	''' <param name="alignToRight"></param>
	''' <remarks></remarks>
	Protected Overrides Sub Paint(ByVal g As System.Drawing.Graphics, ByVal bounds As System.Drawing.Rectangle, ByVal source As System.Windows.Forms.CurrencyManager, ByVal rowNum As Integer, ByVal backBrush As System.Drawing.Brush, ByVal foreBrush As System.Drawing.Brush, ByVal alignToRight As Boolean)

		Try
			'Create a brush for the background
			backBrush = New SolidBrush(SystemColors.Window)

			'Retrieve the value for this cell
			Dim o As Object = Me.GetColumnValueAtRow(source, rowNum)

			'Is this a Null value?
			If o Is DBNull.Value Then
				'Yes, so we'll use grey text
				foreBrush = New SolidBrush(SystemColors.GrayText)
			Else
				'This is a normal value, we'll use the standard foreground text colour
				foreBrush = New SolidBrush(SystemColors.ControlText)
			End If

			'Call into the base class to do the work
			MyBase.Paint(g, bounds, source, rowNum, backBrush, foreBrush, alignToRight)

		Finally
			'Clean up
			If backBrush IsNot Nothing Then backBrush.Dispose()
			If foreBrush IsNot Nothing Then foreBrush.Dispose()
		End Try

	End Sub
End Class
